@@ -17,7 +17,8 @@ rquery_db_info <- function(indentifier_quote_char,
                                          indentifier_quote_char) },
             dbqs = function(s) { paste0(string_quote_char,
                                         s,
-                                        string_quote_char) })
+                                        string_quote_char) },
+            dbql = function(s) { format(s, scientific = 11) })
   class(r) <- "rquery_db_info"
   r
 }
@@ -54,9 +55,32 @@ quote_string <- function (x, s, ...) {
   if(length(list(...))>0) {
     stop("unexpected arguments")
   }
+  s <- as.character(s)
   if("rquery_db_info" %in% class(x)) {
     return(x$dbqs(s))
   }
   as.character(DBI::dbQuoteString(x, s))
 }
 
+#' Quote a value
+#'
+#' @param x DBI database handle or rquery_db_info object.
+#' @param s character to quote
+#' @param ... generic additional arguments (not used)
+#' @return quoted string
+#'
+#' @noRd
+#'
+quote_literal <- function (x, s, ...) {
+  if(length(list(...))>0) {
+    stop("unexpected arguments")
+  }
+  if(is.character(s) || is.factor(s)) {
+    quote_string(x, as.character(s))
+  }
+  if("rquery_db_info" %in% class(x)) {
+    return(x$dbql(s))
+  }
+  as.character(DBI::dbQuoteLiteral(x, s))
+}
+
