@@ -406,11 +406,7 @@ rsummary_node <- function(source,
                      columns_used = columns_used,
                      outgoing_table_name = outgoing_table_name,
                      columns_produced = columns_produced,
-                     display_form = paste0("rsummary_node(., ",
-                                           incoming_table_name,
-                                           ", ",
-                                           outgoing_table_name,
-                                           ")"),
+                     display_form = paste0("rsummary_node(.)"),
                      orig_columns = FALSE,
                      temporary = temporary)
   nd
