@@ -24,9 +24,8 @@ unpack_assignments <- function(source, parsed,
                                ...,
                                have = column_names(source),
                                check_is_assignment = TRUE) {
-  if(length(list(...))>0) {
-    stop("rquery::unpack_assignments unexpected argument")
-  }
+  wrapr::stop_if_dot_args(substitute(list(...)),
+                          "rquery:::unpack_assignments")
   n <- length(parsed)
   if(n<=0) {
     stop("must generate at least 1 column")
@@ -59,17 +58,22 @@ unpack_assignments <- function(source, parsed,
 }
 
 parse_se <- function(source, assignments, env,
-                     have = column_names(source)) {
+                     ...,
+                     have = column_names(source),
+                     check_names = TRUE) {
+  wrapr::stop_if_dot_args(substitute(list(...)),
+                          "rquery:::parse_se")
   n <- length(assignments)
   if(n<=0) {
     stop("must generate at least 1 expression")
   }
+  nms <- names(assignments)
   # R-like db-info for presentation
   db_inf <- rquery_db_info(indentifier_quote_char = '`',
                            string_quote_char = '"')
   parsed <- vector(n, mode = 'list')
   for(i in seq_len(n)) {
-    ni <- names(assignments)[[i]]
+    ni <- nms[[i]]
     ai <- assignments[[i]]
     ei <- parse(text = ai)[[1]]
     pi <- tokenize_for_SQL(ei,
@@ -84,22 +88,35 @@ parse_se <- function(source, assignments, env,
     have <- unique(c(have, pi$symbols_produced))
     parsed[[i]] <- pi
   }
+  if(check_names) {
+    for(i in seq_len(n)) {
+      spi <- parsed[[i]]$symbols_produced
+      if((!is.character(spi)) || (length(spi)!=1) || (nchar(spi)<=0)) {
+        stop("all expressions must have left-hand sides")
+      }
+    }
+  }
   parsed
 }
 
 
 parse_nse <- function(source, exprs, env,
-                      have = column_names(source)) {
+                      ...,
+                      have = column_names(source),
+                      check_names = TRUE) {
+  wrapr::stop_if_dot_args(substitute(list(...)),
+                          "rquery:::parse_nse")
   n <- length(exprs)
   if(n<=0) {
     stop("must have at least 1 assigment")
   }
+  nms <- names(exprs)
   # R-like db-info for presentation
   db_inf <- rquery_db_info(indentifier_quote_char = '`',
                            string_quote_char = '"')
   parsed <- vector(n, mode = 'list')
   for(i in seq_len(n)) {
-    ni <- names(exprs)[[i]]
+    ni <- nms[[i]]
     ei <- exprs[[i]]
     pi <- tokenize_for_SQL(ei,
                         colnames = have,
@@ -113,6 +130,14 @@ parse_nse <- function(source, exprs, env,
     have <- unique(c(have, pi$symbols_produced))
     parsed[[i]] <- pi
   }
+  if(check_names) {
+    for(i in seq_len(n)) {
+      spi <- parsed[[i]]$symbols_produced
+      if((!is.character(spi)) || (length(spi)!=1) || (nchar(spi)<=0)) {
+        stop("all expressions must have left-hand sides")
+      }
+    }
+  }
   parsed
 }
 
@@ -143,12 +168,14 @@ merge_fld <- function(reslist, field) {
 }
 
 
-# mege named maps of column vectors
+# merge named maps of column vectors
+# rquery:::merge_columns_used(list(x = c("a", "b"), y = "c"), list(x = c("d")))
+# should match list(x = c("a", "b", "d"), y = c("c"))
 merge_columns_used <- function(cu1, cu2) {
-  nms <- sort(unique(names(cu1), names(cu2)))
+  nms <- sort(unique(c(names(cu1), names(cu2))))
   cu <- lapply(nms,
                function(ni) {
-                 sort(unique(cu1[[ni]], cu2[[ni]]))
+                 sort(unique(c(cu1[[ni]], cu2[[ni]])))
                })
   names(cu) <- nms
   cu
